ShopifyException class

Exception thrown when an api call fails like when some items are out of stock

Implemented types

Constructors

ShopifyException(String key, String errorKey, {List? errors})
Exception thrown when an api call fails
const

Properties

errorKey → String
The type of the error
final
errors → List?
The list of errors, might contains items out of stock or other item-related errors
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
The shopify operation in which the error occurred
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited