Article class abstract

The article class

Available extensions
Annotations
  • @freezed

Constructors

Article({AuthorV2? author, List<Comment>? commentList, String? content, String? contentHtml, String? excerpt, String? excerptHtml, String? handle, String? id, ShopifyImage? image, String? publishedAt, List<String>? tags, String? title, String? onlineStoreUrl})
The article constructor
const
factory
Article.fromGraphJson(Map<String, dynamic> json)
The article from graph json
factory
Article.fromJson(Map<String, dynamic> json)
The article from json
factory

Properties

author → AuthorV2?
no setterinherited
commentList → List<Comment>?
no setterinherited
content → String?
no setterinherited
contentHtml → String?
no setterinherited
copyWith → $ArticleCopyWith<Article>
Create a copy of Article with the given fields replaced by the non-null parameter values.
no setterinherited
excerpt → String?
no setterinherited
excerptHtml → String?
no setterinherited
handle → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
image → ShopifyImage?
no setterinherited
onlineStoreUrl → String?
no setterinherited
publishedAt → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
no setterinherited
title → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Article value)) → TResult

Available on Article, provided by the ArticlePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Article value)?) → TResult?

Available on Article, provided by the ArticlePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Article value)?, {required TResult orElse()}) → TResult

Available on Article, provided by the ArticlePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(AuthorV2? author, List<Comment>? commentList, String? content, String? contentHtml, String? excerpt, String? excerptHtml, String? handle, String? id, ShopifyImage? image, String? publishedAt, List<String>? tags, String? title, String? onlineStoreUrl)?, {required TResult orElse()}) → TResult

Available on Article, provided by the ArticlePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Article to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(AuthorV2? author, List<Comment>? commentList, String? content, String? contentHtml, String? excerpt, String? excerptHtml, String? handle, String? id, ShopifyImage? image, String? publishedAt, List<String>? tags, String? title, String? onlineStoreUrl)) → TResult

Available on Article, provided by the ArticlePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(AuthorV2? author, List<Comment>? commentList, String? content, String? contentHtml, String? excerpt, String? excerptHtml, String? handle, String? id, ShopifyImage? image, String? publishedAt, List<String>? tags, String? title, String? onlineStoreUrl)?) → TResult?

Available on Article, provided by the ArticlePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited