Articles class

Annotations
  • @freezed

Constructors

Articles({required List<Article> articleList})
factory
Articles.fromJson(Map<String, dynamic> json)
factory

Properties

articleList → List<Article>
no setterinherited
copyWith → $ArticlesCopyWith<Articles>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromGraphJson(Map<String, dynamic> json) → Articles