Comment class

Annotations
  • @freezed

Constructors

Comment({String? email, String? name, String? content, String? contentHtml, String? id})
factory
Comment.fromJson(Map<String, dynamic> json)
factory

Properties

content → String?
no setterinherited
contentHtml → String?
no setterinherited
copyWith → $CommentCopyWith<Comment>
no setterinherited
email → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
name → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromGraphJson(Map<String, dynamic> json) → Comment