Blog class

Annotations
  • @freezed

Constructors

Blog({String? id, String? handle, String? title, String? url, Articles? articles})
factory
Blog.fromJson(Map<String, dynamic> json)
factory

Properties

articles → Articles?
no setterinherited
copyWith → $BlogCopyWith<Blog>
no setterinherited
handle → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
no setterinherited
url → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromGraphJson(Map<String, dynamic> json) → Blog