CartCost class abstract
The cart cost
- Available extensions
- Annotations
-
- @freezed
Constructors
- CartCost({required PriceV2 checkoutChargeAmount, required PriceV2 subtotalAmount, required bool subtotalAmountEstimated, required PriceV2 totalAmount, required bool totalAmountEstimated, PriceV2? totalDutyAmount, required bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, required bool totalTaxAmountEstimated})
-
cart cost factory
constfactory
-
CartCost.fromJson(Map<
String, dynamic> json) -
cart cost from json
factory
Properties
- checkoutChargeAmount → PriceV2
-
no setterinherited
-
copyWith
→ $CartCostCopyWith<
CartCost> -
Create a copy of CartCost
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtotalAmount → PriceV2
-
no setterinherited
- subtotalAmountEstimated → bool
-
no setterinherited
- totalAmount → PriceV2
-
no setterinherited
- totalAmountEstimated → bool
-
no setterinherited
- totalDutyAmount → PriceV2?
-
no setterinherited
- totalDutyAmountEstimated → bool
-
no setterinherited
- totalTaxAmount → PriceV2?
-
no setterinherited
- totalTaxAmountEstimated → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CartCost value)) → TResult -
Available on CartCost, provided by the CartCostPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CartCost value)?) → TResult? -
Available on CartCost, provided by the CartCostPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CartCost value)?, {required TResult orElse()}) → TResult -
Available on CartCost, provided by the CartCostPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(PriceV2 checkoutChargeAmount, PriceV2 subtotalAmount, bool subtotalAmountEstimated, PriceV2 totalAmount, bool totalAmountEstimated, PriceV2? totalDutyAmount, bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, bool totalTaxAmountEstimated)?, {required TResult orElse()}) → TResult -
Available on CartCost, provided by the CartCostPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CartCost to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(PriceV2 checkoutChargeAmount, PriceV2 subtotalAmount, bool subtotalAmountEstimated, PriceV2 totalAmount, bool totalAmountEstimated, PriceV2? totalDutyAmount, bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, bool totalTaxAmountEstimated)) → TResult -
Available on CartCost, provided by the CartCostPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(PriceV2 checkoutChargeAmount, PriceV2 subtotalAmount, bool subtotalAmountEstimated, PriceV2 totalAmount, bool totalAmountEstimated, PriceV2? totalDutyAmount, bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, bool totalTaxAmountEstimated)?) → TResult? -
Available on CartCost, provided by the CartCostPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited