CartCostPatterns extension

Adds pattern-matching-related methods to CartCost.

on

Methods

map<TResult extends Object?>(TResult $default(_CartCost value)) → TResult

Available on CartCost, provided by the CartCostPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CartCost value)?) → TResult?

Available on CartCost, provided by the CartCostPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CartCost value)?, {required TResult orElse()}) → TResult

Available on CartCost, provided by the CartCostPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PriceV2 checkoutChargeAmount, PriceV2 subtotalAmount, bool subtotalAmountEstimated, PriceV2 totalAmount, bool totalAmountEstimated, PriceV2? totalDutyAmount, bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, bool totalTaxAmountEstimated)?, {required TResult orElse()}) → TResult

Available on CartCost, provided by the CartCostPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(PriceV2 checkoutChargeAmount, PriceV2 subtotalAmount, bool subtotalAmountEstimated, PriceV2 totalAmount, bool totalAmountEstimated, PriceV2? totalDutyAmount, bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, bool totalTaxAmountEstimated)) → TResult

Available on CartCost, provided by the CartCostPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PriceV2 checkoutChargeAmount, PriceV2 subtotalAmount, bool subtotalAmountEstimated, PriceV2 totalAmount, bool totalAmountEstimated, PriceV2? totalDutyAmount, bool totalDutyAmountEstimated, PriceV2? totalTaxAmount, bool totalTaxAmountEstimated)?) → TResult?

Available on CartCost, provided by the CartCostPatterns extension

A variant of when that fallback to returning null