Checkout class

Annotations
  • @freezed

Constructors

Checkout({required String id, required bool ready, required AvailableShippingRates? availableShippingRates, required String createdAt, required String currencyCode, required PriceV2 totalTaxV2, required PriceV2 totalPriceV2, required bool taxesIncluded, required bool taxExempt, required PriceV2 subtotalPriceV2, required bool requiresShipping, required List<AppliedGiftCards> appliedGiftCards, required List<LineItem> lineItems, Order? order, String? orderStatusUrl, String? shopifyPaymentsAccountId, MailingAddress? shippingAddress, ShippingRates? shippingLine, String? email, String? completedAt, String? note, String? webUrl, String? updatedAt})
factory
Checkout.fromJson(Map<String, dynamic> json)
factory

Properties

appliedGiftCards → List<AppliedGiftCards>
no setterinherited
availableShippingRates → AvailableShippingRates?
no setterinherited
completedAt → String?
no setterinherited
copyWith → $CheckoutCopyWith<Checkout>
no setterinherited
createdAt → String
no setterinherited
currencyCode → String
no setterinherited
email → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
lineItems → List<LineItem>
no setterinherited
note → String?
no setterinherited
order → Order?
no setterinherited
orderStatusUrl → String?
no setterinherited
ready → bool
no setterinherited
requiresShipping → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress → MailingAddress?
no setterinherited
shippingLine → ShippingRates?
no setterinherited
shopifyPaymentsAccountId → String?
no setterinherited
subtotalPriceV2 → PriceV2
no setterinherited
taxesIncluded → bool
no setterinherited
taxExempt → bool
no setterinherited
totalPriceV2 → PriceV2
no setterinherited
totalTaxV2 → PriceV2
no setterinherited
updatedAt → String?
no setterinherited
webUrl → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited