ShippingRates class abstract

The shipping rates

Available extensions
Annotations
  • @freezed

Constructors

ShippingRates({required String handle, required String title, required PriceV2 priceV2})
The shipping rates constructor
const
factory
ShippingRates.fromJson(Map<String, dynamic> json)
The shipping rates from json
factory

Properties

copyWith → $ShippingRatesCopyWith<ShippingRates>
Create a copy of ShippingRates with the given fields replaced by the non-null parameter values.
no setterinherited
handle String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
priceV2 PriceV2
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ShippingRates value)) → TResult

Available on ShippingRates, provided by the ShippingRatesPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ShippingRates value)?) → TResult?

Available on ShippingRates, provided by the ShippingRatesPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ShippingRates value)?, {required TResult orElse()}) → TResult

Available on ShippingRates, provided by the ShippingRatesPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String handle, String title, PriceV2 priceV2)?, {required TResult orElse()}) → TResult

Available on ShippingRates, provided by the ShippingRatesPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ShippingRates to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String handle, String title, PriceV2 priceV2)) → TResult

Available on ShippingRates, provided by the ShippingRatesPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String handle, String title, PriceV2 priceV2)?) → TResult?

Available on ShippingRates, provided by the ShippingRatesPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited