Collection class

Annotations
  • @freezed

Constructors

Collection({required String title, required String id, required Products products, String? cursor, String? description, String? descriptionHtml, String? handle, String? updatedAt, ShopifyImage? image})
factory
Collection.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $CollectionCopyWith<Collection>
no setterinherited
cursor → String?
no setterinherited
description → String?
no setterinherited
descriptionHtml → String?
no setterinherited
handle → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
image → ShopifyImage?
no setterinherited
imageUrl → String
no setter
products → Products
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setterinherited
updatedAt → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromGraphJson(Map<String, dynamic> json) → Collection