Country class abstract

The country

Available extensions
Annotations
  • @freezed

Constructors

Country({required List<Language> availableLanguages, required Currency currency, required String isoCode, required String name, required String unitSystem})
The country constructor
const
factory
Country.fromJson(Map<String, dynamic> json)
The country from json factory
factory

Properties

availableLanguages List<Language>
no setterinherited
copyWith → $CountryCopyWith<Country>
Create a copy of Country with the given fields replaced by the non-null parameter values.
no setterinherited
currency Currency
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isoCode String
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unitSystem String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Country value)) → TResult

Available on Country, provided by the CountryPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Country value)?) → TResult?

Available on Country, provided by the CountryPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Country value)?, {required TResult orElse()}) → TResult

Available on Country, provided by the CountryPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<Language> availableLanguages, Currency currency, String isoCode, String name, String unitSystem)?, {required TResult orElse()}) → TResult

Available on Country, provided by the CountryPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Country to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<Language> availableLanguages, Currency currency, String isoCode, String name, String unitSystem)) → TResult

Available on Country, provided by the CountryPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<Language> availableLanguages, Currency currency, String isoCode, String name, String unitSystem)?) → TResult?

Available on Country, provided by the CountryPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited