Page class abstract

The Page class

Available extensions
Annotations
  • @freezed

Constructors

Page({required String body, required String bodySummary, required DateTime createdAt, required String handle, required String id, required String title, required DateTime updatedAt, @JsonKey.new(defaultValue: '') required String onlineStoreUrl})
The Page constructor
const
factory
Page.fromGraphJson(Map<String, dynamic> json)
The Page from graph json
factory
Page.fromJson(Map<String, dynamic> json)
The Page from json
factory

Properties

body → String
no setterinherited
bodySummary → String
no setterinherited
copyWith → $PageCopyWith<Page>
Create a copy of Page with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
no setterinherited
handle → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
onlineStoreUrl → String
Nullable on the Storefront API; empty string when absent.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setterinherited
updatedAt → DateTime
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Page value)) → TResult

Available on Page, provided by the PagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Page value)?) → TResult?

Available on Page, provided by the PagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Page value)?, {required TResult orElse()}) → TResult

Available on Page, provided by the PagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String body, String bodySummary, DateTime createdAt, String handle, String id, String title, DateTime updatedAt, String onlineStoreUrl)?, {required TResult orElse()}) → TResult

Available on Page, provided by the PagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Page to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String body, String bodySummary, DateTime createdAt, String handle, String id, String title, DateTime updatedAt, String onlineStoreUrl)) → TResult

Available on Page, provided by the PagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String body, String bodySummary, DateTime createdAt, String handle, String id, String title, DateTime updatedAt, String onlineStoreUrl)?) → TResult?

Available on Page, provided by the PagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited