Metafield class abstract

The Metafield class

Available extensions
Annotations
  • @freezed

Constructors

Metafield({required String id, required String namespace, required String key, required String value, required String type, String? description, Map<String, dynamic>? reference})
The Metafield constructor
const
factory
Metafield.fromGraphJson(Map<String, dynamic> json)
The Metafield from graphjson
factory
Metafield.fromJson(Map<String, dynamic> json)
The Metafield from json
factory

Properties

copyWith → $MetafieldCopyWith<Metafield>
Create a copy of Metafield with the given fields replaced by the non-null parameter values.
no setterinherited
description → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
key → String
no setterinherited
namespace → String
no setterinherited
reference → Map<String, dynamic>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setterinherited
value → String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Metafield value)) → TResult

Available on Metafield, provided by the MetafieldPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Metafield value)?) → TResult?

Available on Metafield, provided by the MetafieldPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Metafield value)?, {required TResult orElse()}) → TResult

Available on Metafield, provided by the MetafieldPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String namespace, String key, String value, String type, String? description, Map<String, dynamic>? reference)?, {required TResult orElse()}) → TResult

Available on Metafield, provided by the MetafieldPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Metafield to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String namespace, String key, String value, String type, String? description, Map<String, dynamic>? reference)) → TResult

Available on Metafield, provided by the MetafieldPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String namespace, String key, String value, String type, String? description, Map<String, dynamic>? reference)?) → TResult?

Available on Metafield, provided by the MetafieldPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited