Shop class abstract

The shop

Available extensions
Annotations
  • @freezed

Constructors

Shop({String? description, String? moneyFormat, String? name, PaymentSettings? paymentSettings, PrimaryDomain? primaryDomain, PrivacyPolicy? privacyPolicy, RefundPolicy? refundPolicy, ShippingPolicy? shippingPolicy, SubscriptionPolicy? subscriptionPolicy, List<String>? shipsToCountries, TermsOfService? termsOfService})
The shop factory constructor
const
factory
Shop.fromJson(Map<String, dynamic> json)
The shop from json
factory

Properties

copyWith → $ShopCopyWith<Shop>
Create a copy of Shop with the given fields replaced by the non-null parameter values.
no setterinherited
description → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
moneyFormat → String?
no setterinherited
name → String?
no setterinherited
paymentSettings → PaymentSettings?
no setterinherited
primaryDomain → PrimaryDomain?
no setterinherited
privacyPolicy → PrivacyPolicy?
no setterinherited
refundPolicy → RefundPolicy?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingPolicy → ShippingPolicy?
no setterinherited
shipsToCountries → List<String>?
no setterinherited
subscriptionPolicy → SubscriptionPolicy?
no setterinherited
termsOfService → TermsOfService?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Shop value)) → TResult

Available on Shop, provided by the ShopPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Shop value)?) → TResult?

Available on Shop, provided by the ShopPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Shop value)?, {required TResult orElse()}) → TResult

Available on Shop, provided by the ShopPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? description, String? moneyFormat, String? name, PaymentSettings? paymentSettings, PrimaryDomain? primaryDomain, PrivacyPolicy? privacyPolicy, RefundPolicy? refundPolicy, ShippingPolicy? shippingPolicy, SubscriptionPolicy? subscriptionPolicy, List<String>? shipsToCountries, TermsOfService? termsOfService)?, {required TResult orElse()}) → TResult

Available on Shop, provided by the ShopPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Shop to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? description, String? moneyFormat, String? name, PaymentSettings? paymentSettings, PrimaryDomain? primaryDomain, PrivacyPolicy? privacyPolicy, RefundPolicy? refundPolicy, ShippingPolicy? shippingPolicy, SubscriptionPolicy? subscriptionPolicy, List<String>? shipsToCountries, TermsOfService? termsOfService)) → TResult

Available on Shop, provided by the ShopPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? description, String? moneyFormat, String? name, PaymentSettings? paymentSettings, PrimaryDomain? primaryDomain, PrivacyPolicy? privacyPolicy, RefundPolicy? refundPolicy, ShippingPolicy? shippingPolicy, SubscriptionPolicy? subscriptionPolicy, List<String>? shipsToCountries, TermsOfService? termsOfService)?) → TResult?

Available on Shop, provided by the ShopPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited