Address class abstract

The address

Available extensions
Annotations
  • @freezed

Constructors

Address({String? id, String? address1, String? address2, String? city, String? company, String? country, String? countryCode, String? firstName, String? lastName, String? formattedArea, String? latitude, String? longitude, String? name, String? phone, String? province, String? provinceCode, String? zip})
The address constructor
const
factory
Address.fromGraphJson(Map<String, dynamic> json)
The address from graphjson factory
factory
Address.fromJson(Map<String, dynamic> json)
The address from json factory
factory

Properties

address1 → String?
no setterinherited
address2 → String?
no setterinherited
city → String?
no setterinherited
company → String?
no setterinherited
copyWith → $AddressCopyWith<Address>
Create a copy of Address with the given fields replaced by the non-null parameter values.
no setterinherited
country → String?
no setterinherited
countryCode → String?
no setterinherited
firstName → String?
no setterinherited
formattedArea → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
lastName → String?
no setterinherited
latitude → String?
no setterinherited
longitude → String?
no setterinherited
name → String?
no setterinherited
phone → String?
no setterinherited
province → String?
no setterinherited
provinceCode → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zip → String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Address value)) → TResult

Available on Address, provided by the AddressPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Address value)?) → TResult?

Available on Address, provided by the AddressPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Address value)?, {required TResult orElse()}) → TResult

Available on Address, provided by the AddressPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, String? address1, String? address2, String? city, String? company, String? country, String? countryCode, String? firstName, String? lastName, String? formattedArea, String? latitude, String? longitude, String? name, String? phone, String? province, String? provinceCode, String? zip)?, {required TResult orElse()}) → TResult

Available on Address, provided by the AddressPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Address to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, String? address1, String? address2, String? city, String? company, String? country, String? countryCode, String? firstName, String? lastName, String? formattedArea, String? latitude, String? longitude, String? name, String? phone, String? province, String? provinceCode, String? zip)) → TResult

Available on Address, provided by the AddressPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, String? address1, String? address2, String? city, String? company, String? country, String? countryCode, String? firstName, String? lastName, String? formattedArea, String? latitude, String? longitude, String? name, String? phone, String? province, String? provinceCode, String? zip)?) → TResult?

Available on Address, provided by the AddressPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited