ShopifyUser class abstract

The shopify user

Available extensions
Annotations
  • @freezed

Constructors

ShopifyUser({Addresses? address, String? createdAt, String? displayName, String? email, String? firstName, String? id, String? lastName, String? phone, List<String>? tags, Address? defaultAddress})
The shopify user constructor
const
factory
ShopifyUser.fromGraphJson(Map<String, dynamic> json)
The shopify user from json factory
factory
ShopifyUser.fromJson(Map<String, dynamic> json)
The shopify user from json factory
factory

Properties

address → Addresses?
no setterinherited
copyWith → $ShopifyUserCopyWith<ShopifyUser>
Create a copy of ShopifyUser with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → String?
no setterinherited
defaultAddress → Address?
no setterinherited
displayName → String?
no setterinherited
email → String?
no setterinherited
firstName → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
lastName → String?
no setterinherited
phone → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ShopifyUser value)) → TResult

Available on ShopifyUser, provided by the ShopifyUserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ShopifyUser value)?) → TResult?

Available on ShopifyUser, provided by the ShopifyUserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ShopifyUser value)?, {required TResult orElse()}) → TResult

Available on ShopifyUser, provided by the ShopifyUserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Addresses? address, String? createdAt, String? displayName, String? email, String? firstName, String? id, String? lastName, String? phone, List<String>? tags, Address? defaultAddress)?, {required TResult orElse()}) → TResult

Available on ShopifyUser, provided by the ShopifyUserPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ShopifyUser to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Addresses? address, String? createdAt, String? displayName, String? email, String? firstName, String? id, String? lastName, String? phone, List<String>? tags, Address? defaultAddress)) → TResult

Available on ShopifyUser, provided by the ShopifyUserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Addresses? address, String? createdAt, String? displayName, String? email, String? firstName, String? id, String? lastName, String? phone, List<String>? tags, Address? defaultAddress)?) → TResult?

Available on ShopifyUser, provided by the ShopifyUserPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited