ShopifyConfig class
The ShopifyConfig class holds the configuration for the Shopify Flutter SDK.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- apiVersion → String
-
The Storefront API Version.
no setter
- fetchPolicy → FetchPolicy?
-
returns
FetchPolicybased on the CachePolicyno setter - graphQLClient → GraphQLClient?
-
The GraphQlClient used for communication with the Storefront API.
no setter
- graphQLClientAdmin → GraphQLClient?
-
The GraphQlClient used for communication with the Storefront API.
no setter
- storeUrl → String?
-
Your store url.
no setter
Static Methods
-
setConfig(
{required String storefrontAccessToken, required String storeUrl, String? adminAccessToken, String storefrontApiVersion = "2024-07", CachePolicy? cachePolicy, String? language, GraphQLCache? storefrontCache, GraphQLCache? adminCache, Duration queryRequestTimeout = const Duration(seconds: 30)}) → void - Sets the config.