ShopifyAuth class

ShopifyAuth class handles the authentication.

Mixed-in types

Properties

accessTokenWithExpDate → Future<AccessTokenWithExpDate?>
Returns the current customer access token.
no setter
currentCustomerAccessToken → Future<String?>
Returns the current customer access token.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAccessTokenExpired → Future<bool>
Returns the bool status if the current access token is expired or not
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForError(QueryResult<Object?> queryResult, {String? key, String? errorKey}) → void
throws a ShopifyException if the operation failed or shopify reports an error.
inherited
createUserWithEmailAndPassword({required String email, required String password, String? phone, String? firstName, String? lastName, bool? acceptsMarketing}) → Future<ShopifyUser>
Tries to create a new user account with the given email address and password.
currentUser({bool forceRefresh = false}) → Future<ShopifyUser?>
Returns the currently signed-in ShopifyUser or null if there is none.
deleteCustomer({required String userId}) → Future<void>
Delete current user and clears it from the disk cache.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renewCurrentAccessToken(String accessToken) → Future<void>
Renews the current access token.
sendPasswordResetEmail({required String email}) → Future<void>
Triggers the Shopify Authentication backend to send a password-reset email to the given email address, which must correspond to an existing user of your app.
signInWithEmailAndPassword({required String email, required String password}) → Future<ShopifyUser>
Tries to sign in a user with the given email address and password.
signInWithMultipassToken(String multipassToken) → Future<ShopifyUser>
Tries to sign in a user with the given Multipass token.
signOutCurrentUser() → Future<void>
Signs out the current user and clears it from the disk cache.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ShopifyAuth
Singleton instance of ShopifyAuth
final