ShopifyBlog class

ShopifyBlog class handles all Blog related things.

Mixed-in types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForError(QueryResult<Object?> queryResult, {String? key, String? errorKey}) → void
throws a ShopifyException if the operation failed or shopify reports an error.
inherited
getAllBlogs({SortKeyBlog sortKeyBlog = SortKeyBlog.HANDLE, bool reverseBlogs = false, bool reverseArticles = false}) → Future<List<Blog>>
Returns a List of Blog.
getBlogByHandle(String handle, {SortKeyArticle sortKeyArticle = SortKeyArticle.RELEVANCE, bool reverse = false}) → Future<Blog>
Returns a Blog.
getXArticlesSorted(int articleAmount, {SortKeyArticle sortKeyArticle = SortKeyArticle.RELEVANCE}) → Future<List<Article>>
Returns a List of Article.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ShopifyBlog
Singleton instance of ShopifyBlog
final