ShopifyPage class

ShopifyPage class handles all Page related things.

Mixed-in types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForError(QueryResult<Object?> queryResult, {String? key, String? errorKey}) → void
throws a ShopifyException if the operation failed or shopify reports an error.
inherited
getAllPages({SortKeyPage sortKeyPage = SortKeyPage.ID, bool reversePages = false, String? pagesQuery}) → Future<List<Page>>
Returns a List of Page.
getPageByHandle(String handle) → Future<Page>
Returns a Page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ShopifyPage
Singleton instance of ShopifyPage
final