Article class

Annotations
  • @freezed

Constructors

Article({AuthorV2? author, List<Comment>? commentList, String? content, String? contentHtml, String? excerpt, String? excerptHtml, String? handle, String? id, ShopifyImage? image, String? publishedAt, List<String>? tags, String? title, String? url})
factory
Article.fromJson(Map<String, dynamic> json)
factory

Properties

author → AuthorV2?
no setterinherited
commentList → List<Comment>?
no setterinherited
content → String?
no setterinherited
contentHtml → String?
no setterinherited
copyWith → $ArticleCopyWith<Article>
no setterinherited
excerpt → String?
no setterinherited
excerptHtml → String?
no setterinherited
handle → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
image → ShopifyImage?
no setterinherited
publishedAt → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
no setterinherited
title → String?
no setterinherited
url → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromGraphJson(Map<String, dynamic> json) → Article