models/src/cart/cart_model library
Classes
- Cart
- The cart
- CartAddressInput
-
Exactly one kind of delivery address: either an address stored on the cart
(
deliveryAddress) or a copy of one of the customer's saved addresses (copyFromCustomerAddressId). - CartBuyerIdentity
- The buyer identity of a cart
- CartBuyerIdentityInput
- the cart buyer identity input
- CartCost
- The cart cost
- CartDelivery
- The delivery information of a cart.
- CartDeliveryAddress
- A delivery address stored on the cart.
- CartDeliveryAddressInput
- A delivery address to store on a cart.
- CartDeliveryCoordinatesPreference
- The cart delivery coordinates preference
- CartDeliveryInput
- The delivery-related fields of a cart.
- CartDeliveryPreference
- The cart delivery preference
- CartDiscountAllocation
- The cart discount allocation
- CartDiscountCode
- The CartDiscountCode class
- CartInput
- The cart input
- CartLineCost
- The cart line cost
- CartLineInput
- The cart line input
- CartLineUpdateInput
- The cart line input
- CartPreference
- The cart preference
- CartSelectableAddress
- A delivery address presented to the buyer on the cart, along with whether it is the pre-selected one.
- CartSelectableAddressInput
- A delivery address to present to the buyer on the cart.
- Customer
- The cart customer
- Line
- The cart line
- Lines
- The cart lines
- MailingAddressInput
- The mailing address input
Extensions
- CartAddressInputPatterns on CartAddressInput
- Adds pattern-matching-related methods to CartAddressInput.
- CartBuyerIdentityInputPatterns on CartBuyerIdentityInput
- Adds pattern-matching-related methods to CartBuyerIdentityInput.
- CartBuyerIdentityPatterns on CartBuyerIdentity
- Adds pattern-matching-related methods to CartBuyerIdentity.
- CartCostPatterns on CartCost
- Adds pattern-matching-related methods to CartCost.
- CartDeliveryAddressInputPatterns on CartDeliveryAddressInput
- Adds pattern-matching-related methods to CartDeliveryAddressInput.
- CartDeliveryAddressPatterns on CartDeliveryAddress
- Adds pattern-matching-related methods to CartDeliveryAddress.
- CartDeliveryCoordinatesPreferencePatterns on CartDeliveryCoordinatesPreference
- Adds pattern-matching-related methods to CartDeliveryCoordinatesPreference.
- CartDeliveryInputPatterns on CartDeliveryInput
- Adds pattern-matching-related methods to CartDeliveryInput.
- CartDeliveryPatterns on CartDelivery
- Adds pattern-matching-related methods to CartDelivery.
- CartDeliveryPreferencePatterns on CartDeliveryPreference
- Adds pattern-matching-related methods to CartDeliveryPreference.
- CartDiscountAllocationPatterns on CartDiscountAllocation
- Adds pattern-matching-related methods to CartDiscountAllocation.
- CartDiscountCodePatterns on CartDiscountCode
- Adds pattern-matching-related methods to CartDiscountCode.
- CartInputPatterns on CartInput
- Adds pattern-matching-related methods to CartInput.
- CartLineCostPatterns on CartLineCost
- Adds pattern-matching-related methods to CartLineCost.
- CartLineInputPatterns on CartLineInput
- Adds pattern-matching-related methods to CartLineInput.
- CartLineUpdateInputPatterns on CartLineUpdateInput
- Adds pattern-matching-related methods to CartLineUpdateInput.
- CartPatterns on Cart
- Adds pattern-matching-related methods to Cart.
- CartPreferencePatterns on CartPreference
- Adds pattern-matching-related methods to CartPreference.
- CartSelectableAddressInputPatterns on CartSelectableAddressInput
- Adds pattern-matching-related methods to CartSelectableAddressInput.
- CartSelectableAddressPatterns on CartSelectableAddress
- Adds pattern-matching-related methods to CartSelectableAddress.
- CustomerPatterns on Customer
- Adds pattern-matching-related methods to Customer.
- LinePatterns on Line
- Adds pattern-matching-related methods to Line.
- LinesPatterns on Lines
- Adds pattern-matching-related methods to Lines.
- MailingAddressInputPatterns on MailingAddressInput
- Adds pattern-matching-related methods to MailingAddressInput.