TokanizedCheckout class abstract
The tokanized checkout
- Available extensions
- Annotations
-
- @freezed
Constructors
- TokanizedCheckout({@JsonKey.new(name: 'id') required String paymentId, required PriceV2 amountV2, required bool test, required bool ready, String? nextActionUrl, String? errorMessage, @JsonKey.new(name: 'checkout', fromJson: _checkoutIdFromJson) String? checkoutId})
-
The tokanized checkout constructor
constfactory
-
TokanizedCheckout.fromJson(Map<
String, dynamic> json) -
The tokanized checkout from json
factory
Properties
- amountV2 → PriceV2
-
no setterinherited
- checkoutId → String?
-
no setterinherited
-
copyWith
→ $TokanizedCheckoutCopyWith<
TokanizedCheckout> -
Create a copy of TokanizedCheckout
with the given fields replaced by the non-null parameter values.
no setterinherited
- errorMessage → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextActionUrl → String?
-
no setterinherited
- paymentId → String
-
no setterinherited
- ready → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- test → bool
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TokanizedCheckout value)) → TResult -
Available on TokanizedCheckout, provided by the TokanizedCheckoutPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TokanizedCheckout value)?) → TResult? -
Available on TokanizedCheckout, provided by the TokanizedCheckoutPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TokanizedCheckout value)?, {required TResult orElse()}) → TResult -
Available on TokanizedCheckout, provided by the TokanizedCheckoutPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String paymentId, PriceV2 amountV2, bool test, bool ready, String? nextActionUrl, String? errorMessage, String? checkoutId)?, {required TResult orElse()}) → TResult -
Available on TokanizedCheckout, provided by the TokanizedCheckoutPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TokanizedCheckout to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String paymentId, PriceV2 amountV2, bool test, bool ready, String? nextActionUrl, String? errorMessage, String? checkoutId)) → TResult -
Available on TokanizedCheckout, provided by the TokanizedCheckoutPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String paymentId, PriceV2 amountV2, bool test, bool ready, String? nextActionUrl, String? errorMessage, String? checkoutId)?) → TResult? -
Available on TokanizedCheckout, provided by the TokanizedCheckoutPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited