Shop class

Annotations
  • @freezed

Constructors

Shop({String? description, String? moneyFormat, String? name, PaymentSettings? paymentSettings, PrimaryDomain? primaryDomain, PrivacyPolicy? privacyPolicy, RefundPolicy? refundPolicy, List<String>? shipsToCountries, TermsOfService? termsOfService})
factory
Shop.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ShopCopyWith<Shop>
no setterinherited
description → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
moneyFormat → String?
no setterinherited
name → String?
no setterinherited
paymentSettings → PaymentSettings?
no setterinherited
primaryDomain → PrimaryDomain?
no setterinherited
privacyPolicy → PrivacyPolicy?
no setterinherited
refundPolicy → RefundPolicy?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipsToCountries → List<String>?
no setterinherited
termsOfService → TermsOfService?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited