ShopifyUser class

Annotations
  • @freezed

Constructors

ShopifyUser({Addresses? address, String? createdAt, String? displayName, String? email, String? firstName, String? id, String? lastName, String? phone, List<String>? tags, LastIncompleteCheckout? lastIncompleteCheckout})
factory
ShopifyUser.fromJson(Map<String, dynamic> json)
factory

Properties

address → Addresses?
no setterinherited
copyWith → $ShopifyUserCopyWith<ShopifyUser>
no setterinherited
createdAt → String?
no setterinherited
displayName → String?
no setterinherited
email → String?
no setterinherited
firstName → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setterinherited
lastIncompleteCheckout → LastIncompleteCheckout?
no setterinherited
lastName → String?
no setterinherited
phone → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromGraphJson(Map<String, dynamic> json) → ShopifyUser